package ifneeded Tcldot 2.40.1 "
	load [file join $dir cygtcldot.dll] Tcldot"
package ifneeded Tclpathplan 2.40.1 "
	load [file join $dir cygtclplan.dll] Tclpathplan"
package ifneeded Gdtclft 2.40.1 "
	load [file join $dir cyggdtclft.dll] Gdtclft"
package ifneeded gv 0 "
	load [file join $dir cyggv_tcl.dll] gv"
# end
